"""
Keys used for initializing the module or Decoder APIs

    # generate a private key (will ask for a password)
    $ openssl genrsa -des3 -out test.pem 2048

    # enter the password when asked
    $ openssl rsa -in test.pem -outform PEM -out test.pem

    # use the private key to request a certificate
    $ openssl req -new -x509 -key test.pem -out test.cert -days 3650

    $ ls
    test.pem  test.cert
"""

CERTIFICATE = """\
-----BEGIN CERTIFICATE-----
MIIDXTCCAkWgAwIBAgIJAOrnh02g6rrRMA0GCSqGSIb3DQEBCwUAMEUxCzAJBgNV
BAYTAkFVMRMwEQYDVQQIDApTb21lLVN0YXRlMSEwHwYDVQQKDBhJbnRlcm5ldCBX
aWRnaXRzIFB0eSBMdGQwHhcNMTcwNTMwMTkyNDQxWhcNMjcwNTI4MTkyNDQxWjBF
MQswCQYDVQQGEwJBVTETMBEGA1UECAwKU29tZS1TdGF0ZTEhMB8GA1UECgwYSW50
ZXJuZXQgV2lkZ2l0cyBQdHkgTHRkMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB
CgKCAQEAtY/BVyFxLE27xgSa8ti3EO4VV+WWZFreQbdRIMciAzMsH5npYDCXxPmg
1mZlsDMECD8JMeZmTmCAcsVaI3ixw+XtpuPqu12E2hwIfaj03MMJT2aPvzp0jdQ9
zY0J0zTy9zlApyc97TPtSlV//5udh67/N69vggkZSIu2N/DkF6XYM9QDmSs1e1YB
BDg6M1QNlDy5eAlY7KSzn5GYRymLUgilsnLV/6DPX8c18V6g0QZnNYG9rTr05gSN
t6cuZnk6veGKnogeyzMW44BplZ3nepDFFfOuFS4/IVO+EjlcVY5eGJw4l2ddN7UI
nfg1Bwq1jZMiLBSotsUZ894VxIgxTQIDAQABo1AwTjAdBgNVHQ4EFgQUZXpNrC1B
juWvJz8r+pZP56PzPuowHwYDVR0jBBgwFoAUZXpNrC1BjuWvJz8r+pZP56PzPuow
DAYDVR0TBAUwAwEB/zANBgkqhkiG9w0BAQsFAAOCAQEAgolff4q3Q9v0qHacJgJC
iNMh+LWP1CIHL6MQralMxrGrUdAEM+N053j5aMrNTlwQbjb4I55eEl/EK7teQ/H0
u5BBswUI+H44xp9PlYGLPaLQYVc1QxWRtP90nHdUrE4OPOI1/7iGqAuqHfIFEpQi
PEvQnsZDgGHgicERbIjiG+4ASiNw1weKWC1BjFaGv11WiuLye8N7QDuMwJe2Ewbs
PNAOHffL85aNvz7s5KIkNYOqx+BwErOGjhTOxeNGUeBWnTT/eA0hAc1M3pTPyFxd
2tVs3kQc8LfYsY7Z/Svo44dHVQvOXkkkGqial/Oe8EA0ZutbUbdJDgM+vMpmPLuT
jg==
-----END CERTIFICATE-----
"""

PRIVATE_KEY = """\
-----BEGIN RSA PRIVATE KEY-----
MIIEpAIBAAKCAQEAtY/BVyFxLE27xgSa8ti3EO4VV+WWZFreQbdRIMciAzMsH5np
YDCXxPmg1mZlsDMECD8JMeZmTmCAcsVaI3ixw+XtpuPqu12E2hwIfaj03MMJT2aP
vzp0jdQ9zY0J0zTy9zlApyc97TPtSlV//5udh67/N69vggkZSIu2N/DkF6XYM9QD
mSs1e1YBBDg6M1QNlDy5eAlY7KSzn5GYRymLUgilsnLV/6DPX8c18V6g0QZnNYG9
rTr05gSNt6cuZnk6veGKnogeyzMW44BplZ3nepDFFfOuFS4/IVO+EjlcVY5eGJw4
l2ddN7UInfg1Bwq1jZMiLBSotsUZ894VxIgxTQIDAQABAoIBAFuYCCuSnWuCU6ZU
EG9O0RvjYDUVh8dc6B8zAeSNUSVYHXxbwxZZrVcbr/45bjdzpScb1eGsoBQOLv63
fP/EFboENt4owPSA+1KlLctm/xCX/Axoa0BHlyEt33fhHQHGBoSeB3XMIDuYJK+J
bqdetBwNNoe7I3/wYybsBKM4DXm3wUgbkVGk3IlH6iZb/BP+sRshK7MEJw5qwLcJ
TCDXvcWO8+pFbo9ax9XVsS7ZL2B4lSgRwPqkjg1hkyv4bjtKTE6wdI5EfWW9QWsd
P24q7ThsPdsaeH5ZmyWhUHV7RcTwVqCSFGn1FRtmmkPjDvVv4yJnefq55rqOr1pa
HtrHgQECgYEA26c8CrXwh/oOdac7Nn76k47S/SKxkbXgbGDOxU3a5eVfxW6QdUnN
FTLxrLqHnFRTCooYrBuj9hNuocgtkQe/ISnK9S4kP6KZ1zVW6DLqjT8odtQTNmXb
VkoYR4EIZDGPK5IHRL0ZWjSzc1rkCUUfhVy6uvsl0xdCqnfXastLgiECgYEA05rp
Ywj/kOqomZPK3gL3XSwIehEspiGdPqL0qirBVMdLQFy2p3m3HYNvkWL84RK62DpP
B0hr/DiwJpWsq7Jg50GyTUis/90FiKXTUkAiCTrC3bG65saFbc9Yp1eR2xpFUlO4
XI2+3avOc1/vPuECFnNiWZPL/rwpy0MmW8VbIa0CgYEA1mQpr46b4izItj9vBSb1
LtdFyrt1M/KgxUfMKjpugNvcGZlsOH67RIi/6Mb7nDOWBgB6SmqEI6gd4JzBFQDJ
pfXj2mGaEd6EZ9DxLZyc4RaXSTyAMCVE67lQb2JbLWhOBMn4fDhSKYCs8tfxIbct
J/81Z1HBPoNCl553TQ52eeECgYEAyscRzmDqH6JvzTRu3M/04ml2+hsJMW7W9BZO
5d8xA6A0AcqXEui1zOeOe8FjWgCL4vgFkZIaQUrFq0QVgzfeWt5/EkaJ2mugiPF4
D8L7muKfqLlPxSUK6k8fwsVNNaz4L0uhSbhf5qdkoPWXHCedy4vo/LSAcW05k9qW
oK0AhsUCgYA+50EYkwHCDTnbP+ve68n9uOSAYtjYmGT2QJRjqCJYRzlW33UwfwkQ
Th+uHrkjIf4PaHSkmhGwz4iljGK6ALLSrlXayD2Jz22TM92OCtiLVorqcCfIaa+9
qGzKQXsItBI0G6XCx5BS61QTIipi/jIyERsyJWNTLJsd+kmRPXz/Lg==
-----END RSA PRIVATE KEY-----
"""
